using System;
using System.Collections.Generic;
using System.Text;
using javax.naming;
using javax.rmi;
using java.util;
using java.lang;
using com.jnbridge.demo.calculator;

namespace GlassFish21Example
{
    class Program
    {
        static void Main(string[] args)
        {
            string hostName = "";     // edit host name or IP address
            string portNumber = "";  // edit with valid GlassFish iiop port, usually '3700'
            string login = "";            // edit with a login, if required by GlassFish implementation
            string passWord = "";     // edit with pass wprd, if required by GlassFish implementation     

            try
            {
                Console.WriteLine("Getting InitialContext");
                InitialContext jndiContext = (InitialContext)getInitialContext(hostName, portNumber, login, passWord);
                Console.WriteLine("got context");

                java.lang.Object objRef = jndiContext.lookup("com.jnbridge.demo.calculator.CalculatorHome");
                CalculatorHome home = (CalculatorHome)
                    PortableRemoteObject.narrow(objRef, java.lang.Class.forName("com.jnbridge.demo.calculator.CalculatorHome"));
                Console.WriteLine("got reference");

                Calculator remote = home.create();
                Console.WriteLine("Created calculator bean");

                double result;
                double op1 = 5.3;
                double op2 = 2.1;

                result = remote.add(op1, op2);
                Console.WriteLine("add({0}, {1}) = {2}", op1, op2, result);

                result = remote.subtract(op1, op2);
                Console.WriteLine("subtract({0}, {1}) = {2}", op1, op2, result);

                result = remote.multiply(op1, op2);
                Console.WriteLine("multiply({0}, {1}) = {2}", op1, op2, result);

                result = remote.divide(op1, op2);
                Console.WriteLine("divide({0}, {1}) = {2}", op1, op2, result);
            }
            catch ( java.lang.Exception ex )
            {
                Console.WriteLine(ex.JavaExceptionClass);
                Console.WriteLine(ex.JavaExceptionMessage);
                Console.WriteLine(ex.JavaStackTrace);
            }
        }

        private static Context getInitialContext(string hostName, string portNumber, string login, string passWord)
        {
            string url = "iiop://" + hostName + ":" + portNumber + "/";

            try
            {
                Properties h = new Properties();
                h.put((java.lang.JavaString)ContextConstants.INITIAL_CONTEXT_FACTORY
                    , (java.lang.JavaString)"com.sun.enterprise.naming.SerialInitContextFactory");

                h.put((java.lang.JavaString)ContextConstants.PROVIDER_URL
                    , (java.lang.JavaString)url);

                h.put((java.lang.JavaString)"org.omg.CORBA.ORBInitialHost", (java.lang.JavaString)hostName);


                if ( !string.IsNullOrEmpty(login) )
                {
                    h.put((java.lang.JavaString)ContextConstants.SECURITY_AUTHENTICATION
                        , (java.lang.JavaString)"simple");
                    h.put(new java.lang.JavaString(ContextConstants.SECURITY_PRINCIPAL)
                        , (java.lang.JavaString)login);
                    h.put(new java.lang.JavaString(ContextConstants.SECURITY_CREDENTIALS)
                        , (java.lang.JavaString)passWord);
                }

                return new InitialContext(h);
            }
            catch ( NamingException ne )
            {
                Console.WriteLine("Unable to get a connection to the GlassFish server at, " + hostName + ", with port: " + portNumber);
                Console.WriteLine("Please make sure that the server is running.");
                throw ne;
            }
        }
    }
}
